# This controls "import *" and actually imports only what is defined here
__all__ = ["ssh_host", "ssh_port", "creds_path", "global_config", "local_config", "provider"]

# These should not be modified here!
ssh_host = ""
ssh_port = ""
creds_path = ""
global_config = ""
local_config = ""
provider = None